@@ -13,26 +13,26 @@
 #include "common.h"
 #include "entireDB.h"
 extern struct main_components components;
-extern int connected;
+extern INT connected;
 extern PGconn* connection;
-extern int want_all_elems;
-extern int max_tabs;
-extern int cont;
-extern char* currentbase;
+extern INT want_all_elems;
+extern INT max_tabs;
+extern INT cont;
+extern CHAR* currentbase;
 struct ProgressData *pdata;
 
-GtkWidget* construct_view_table(char* tabname)
+GtkWidget* construct_view_table(CHAR* tabname)
 {
- char*** ptr;
- int row,col;
- char errstr[MAX_QUERY_LENGTH+100];
+ CHAR*** ptr;
+ INT row,col;
+ CHAR errstr[MAX_QUERY_LENGTH+100];
  struct result_cache res_cache;
 #ifdef SMALLOC
  struct dmem_list *memory;
 #else
  struct mem_list *memory;
 #endif
- int i,j,orow,ocol;
+ INT i,j,orow,ocol;
  GtkWidget*** table_entry;
  GtkWidget* table_view;
  GtkWidget* scroller_view;
@@ -90,7 +90,8 @@ GtkWidget* construct_view_table(char* tabname)
  return scroller_view;
 }
 
-int drop_control(GtkWidget* w, gpointer data)
+
+INT drop_control(GtkWidget* w, gpointer data)
 {
  debug("%s:%d drop_control()",__FILE__,__LINE__);
  create_pbar("freeing memory...");
@@ -98,12 +99,14 @@ int drop_control(GtkWidget* w, gpointer data)
  return FALSE;
 }
 
+
 void rotate_book(GtkButton *button,GtkNotebook *notebook)
 {
  debug("%s:%d rotate_book()",__FILE__,__LINE__);
  gtk_notebook_set_tab_pos(notebook,(notebook->tab_pos+1)%4);
 }
 
+
 void write_html_header(FILE* f)
 {
  debug("%s:%d write_html_header()",__FILE__,__LINE__);
@@ -116,6 +119,7 @@ void write_html_header(FILE* f)
  fprintf(f,"<BODY>\n");
 }
 
+
 void write_html_end(FILE* f)
 {
  debug("%s:%d write_html_end()",__FILE__,__LINE__);
@@ -123,11 +127,12 @@ void write_html_end(FILE* f)
  fprintf(f,"</HTML>\n");
 }
 
-int save_table(FILE* f, char** tables, int page, int ntabs, int fast)
+
+INT save_table(FILE* f, CHAR** tables, INT page, INT ntabs, INT fast)
 {
- int start,want_meta,i,j,row,col;
- char errstr[MAX_QUERY_LENGTH+100];
- char*** ptr;
+ INT start,want_meta,i,j,row,col;
+ CHAR errstr[MAX_QUERY_LENGTH+100];
+ CHAR*** ptr;
 #ifdef SMALLOC
  struct dmem_list* mem;
 #else
@@ -172,6 +177,7 @@ int save_table(FILE* f, char** tables, int page, int ntabs, int fast)
  return 1;
 }
 
+
 void save_entire_book(GtkButton *button, GtkNotebook *notebook)
 {
 #ifdef SMALLOC
@@ -179,22 +185,22 @@ void save_entire_book(GtkButton *button, GtkNotebook *notebook)
 #else
  struct mem_list* memory;
 #endif
- char** tables;
- char* filen;
- int ntabs,a,i;
+ CHAR** tables;
+ CHAR* filen;
+ INT ntabs,a,i;
  void* tmp;
  FILE* f;
  debug("%s:%d save_entire_book()",__FILE__,__LINE__);
  tmp=NULL;
  memory = NULL;
 #ifdef SMALLOC
- if (!dmem_get_db_tables(&memory, connection,&tables, &ntabs, want_all_elems,HERE)) 
+ if (!dmem_get_db_tables(&memory, connection,&tables, &ntabs, want_all_elems,HERE))
 #else
- if (!mem_get_db_tables(&memory, connection,&tables, &ntabs, want_all_elems)) 
+ if (!mem_get_db_tables(&memory, connection,&tables, &ntabs, want_all_elems))
 #endif
-    { 
-     gtk_dialog_printf("Cannot get DB tables list!\n"); 
-     return; 
+    {
+     gtk_dialog_printf("Cannot get DB tables list!\n");
+     return;
     }
  if (ntabs<=0) { gtk_dialog_printf("No tables detected!"); return; }
  filen = gtk_dialog_getfile(".HTML", "Save Results to: (*.HTML)");
@@ -218,7 +224,7 @@ void save_entire_book(GtkButton *button, GtkNotebook *notebook)
    }
  write_html_header(f);
  fprintf(f,"<CENTER><BIG><BIG> DataBase: %s </BIG></BIG></CENTER>\n", currentbase);
- for (i=0;i<ntabs;i++) 
+ for (i=0;i<ntabs;i++)
    {
     fprintf(f, "<CENTER><BIG>table: %s</BIG></CENTER>\n", tables[i]);
     if (!save_table(f, tables, i, ntabs, 1)) break;
@@ -231,28 +237,29 @@ void save_entire_book(GtkButton *button, GtkNotebook *notebook)
  dshred_special_memlist(&memory, HERE);
 #else
  for (i=0;i<ntabs;i++) if (tables[i]) { sfree(&memory, (void**)(&tables[i])); tables[i] = NULL; }
- if (tables) 
+ if (tables)
    {
     tmp = (void*)tables;
-    sfree(&memory, &tmp); 
-    tables = NULL; 
+    sfree(&memory, &tmp);
+    tables = NULL;
    }
  shred_special_memlist(&memory);
 #endif
 }
 
+
 void save_table_book(GtkButton *button, GtkNotebook *notebook)
 {
- int page;
+ INT page;
 #ifdef SMALLOC
  struct dmem_list* memory;
 #else
  struct mem_list* memory;
 #endif
- char** tables;
- char* filen;
+ CHAR** tables;
+ CHAR* filen;
  void* tmp;
- int ntabs,a,i;
+ INT ntabs,a,i;
  FILE* f;
  debug("%s:%d save_table_book()",__FILE__,__LINE__);
  memory = NULL;
@@ -260,13 +267,13 @@ void save_table_book(GtkButton *button, GtkNotebook *notebook)
  page = gtk_notebook_get_current_page(notebook);
  debug("PAGE=%d\n",page);
 #ifdef SMALLOC
- if (!dmem_get_db_tables(&memory, connection,&tables, &ntabs, want_all_elems, HERE)) 
+ if (!dmem_get_db_tables(&memory, connection,&tables, &ntabs, want_all_elems, HERE))
 #else
- if (!mem_get_db_tables(&memory, connection,&tables, &ntabs, want_all_elems)) 
+ if (!mem_get_db_tables(&memory, connection,&tables, &ntabs, want_all_elems))
 #endif
-    { 
-     gtk_dialog_printf("Cannot get DB tables list!\n"); 
-     return; 
+    {
+     gtk_dialog_printf("Cannot get DB tables list!\n");
+     return;
     }
  if (ntabs<=0) { gtk_dialog_printf("No tables detected!"); return; }
  filen = gtk_dialog_getfile(".HTML", "Save Results to: (*.HTML)");
@@ -296,34 +303,37 @@ void save_table_book(GtkButton *button, GtkNotebook *notebook)
  dshred_special_memlist(&memory, HERE);
 #else
  for (i=0;i<ntabs;i++) if (tables[i]) { sfree(&memory, (void**)(&tables[i])); tables[i] = NULL; }
- if (tables) 
-   { 
+ if (tables)
+   {
     tmp = (void*)tables;
-    sfree(&memory, &tmp); 
-    tables = NULL; 
+    sfree(&memory, &tmp);
+    tables = NULL;
    }
  shred_special_memlist(&memory);
 #endif
 }
 
+
 void tabsborder_book(GtkButton *button, GtkNotebook *notebook)
 {
- int tval = FALSE;
- int bval = FALSE;
+ INT tval = FALSE;
+ INT bval = FALSE;
  debug("%s:%d tabsborder_book()",__FILE__,__LINE__);
- if (notebook->show_tabs == 0)   tval = TRUE; 
+ if (notebook->show_tabs == 0)   tval = TRUE;
  if (notebook->show_border == 0) bval = TRUE;
  gtk_notebook_set_show_tabs(notebook, tval);
  gtk_notebook_set_show_border(notebook, bval);
 }
 
-void create_pbar(char* arg)
+
+void create_pbar(CHAR* arg)
 {
  debug("%s:%d create_pbar(%s)",__FILE__,__LINE__,arg);
  cont=1;
  system_printf("pbar %d '%s' 1>/dev/null 2>/dev/null &", getpid(), arg);
 }
 
+
 void destroy_pbar()
 {
  debug("%s:%d destroy_pbar()",__FILE__,__LINE__);
@@ -331,6 +341,7 @@ void destroy_pbar()
  cont=1;
 }
 
+
 void cmenu_browse_all(GtkWidget* w, gpointer data)
 {
  GtkWidget *window;
@@ -339,38 +350,36 @@ void cmenu_browse_all(GtkWidget* w, gpointer data)
  GtkWidget *notebook;
  GtkWidget *frame;
  GtkWidget *label;
- GtkWidget *scroller; 
+ GtkWidget *scroller;
  GtkWidget *vtable;
 #ifdef SMALLOC
  struct dmem_list* memoryl;
 #else
  struct mem_list* memoryl;
 #endif
- char** tables;
+ CHAR** tables;
  void*  tmp;
- int ntabs;
- int i;
+ INT ntabs;
+ INT i;
  debug("%s:%d cmenu_browse_all()",__FILE__,__LINE__);
  memoryl=NULL;
  tmp=NULL;
  if (!connected)  { gtk_dialog_printf("Not connected to DB!"); return; }
 #ifdef SMALLOC
- if (!dmem_get_db_tables(&memoryl, connection,&tables, &ntabs, want_all_elems, HERE)) 
+ if (!dmem_get_db_tables(&memoryl, connection,&tables, &ntabs, want_all_elems, HERE))
 #else
- if (!mem_get_db_tables(&memoryl, connection,&tables, &ntabs, want_all_elems)) 
+ if (!mem_get_db_tables(&memoryl, connection,&tables, &ntabs, want_all_elems))
 #endif
-   { 
-    gtk_dialog_printf("Cannot get DB tables list!\n"); 
-    return; 
+   {
+    gtk_dialog_printf("Cannot get DB tables list!\n");
+    return;
    }
  if (ntabs<=0) { gtk_dialog_printf("No tables detected!"); return; }
  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_usize(window, 800,600);
  gtk_window_set_title (GTK_WINDOW(window), "Preview of DB (results will be truncated if too long)");
  gtk_window_set_modal(GTK_WINDOW(window), TRUE);
- 
  table = gtk_table_new(8,10,FALSE);
- 
  notebook = gtk_notebook_new();
  gtk_notebook_set_tab_pos(GTK_NOTEBOOK (notebook), GTK_POS_TOP);
  scroller = gtk_scrolled_window_new(NULL,NULL);
@@ -378,12 +387,9 @@ void cmenu_browse_all(GtkWidget* w, gpointer data)
  gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scroller), notebook);
  gtk_container_set_border_width(GTK_CONTAINER(scroller), 2);
  gtk_widget_show(scroller);
- 
  gtk_container_set_border_width (GTK_CONTAINER (window), 1);
-
  gtk_table_attach(GTK_TABLE(table), scroller, 0,8,0,9, GTK_FILL|GTK_EXPAND,GTK_FILL|GTK_EXPAND,0,0);
  gtk_widget_show(notebook);
- 
  gtk_signal_connect (GTK_OBJECT (window), "delete_event",GTK_SIGNAL_FUNC(drop_control), (gpointer)(window));
  gtk_container_add (GTK_CONTAINER(window), table);
  if (ntabs>max_tabs) ntabs=max_tabs;
@@ -392,23 +398,19 @@ void cmenu_browse_all(GtkWidget* w, gpointer data)
      {
       debug("TABLES[%d] = %s\n", i, tables[i]);
       frame = gtk_frame_new (tables[i]);
-      
       gtk_container_set_border_width (GTK_CONTAINER(frame),2);
-      
       gtk_widget_set_usize (frame, 100, 25);
       gtk_widget_show(frame);
-      
       label = gtk_label_new(tables[i]);
       gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, label);
-
       vtable = construct_view_table(tables[i]);
       if (vtable) gtk_container_add(GTK_CONTAINER(frame), construct_view_table(tables[i]));
       else gtk_container_add(GTK_CONTAINER(frame), gtk_label_new("Connot read table!"));
-      if (!cont) 
-        { 
+      if (!cont)
+        {
          gtk_window_set_title (GTK_WINDOW(window), "Preview of DB, incomplete - interrupted!");
-         gtk_dialog_printf("Interrupted!"); 
-	 break; 
+         gtk_dialog_printf("Interrupted!");
+	 break;
 	}
     }
  destroy_pbar();
@@ -448,20 +450,20 @@ void cmenu_browse_all(GtkWidget* w, gpointer data)
  if (GTK_IS_WIDGET(window)) gtk_widget_destroy(window);
 #ifdef SMALLOC
  for (i=0;i<ntabs;i++) if (tables[i]) { dsfree(&memoryl, (void**)(&tables[i]), HERE); tables[i]=NULL; }
- if (tables) 
+ if (tables)
    { dsfree(&memoryl, (void**)(&tables), HERE); tables=NULL; }
  dshred_special_memlist(&memoryl, HERE);
 #else
- for (i=0;i<ntabs;i++) if (tables[i]) 
-   { 
-    sfree(&memoryl, (void**)(&tables[i])); 
-    tables[i]=NULL; 
+ for (i=0;i<ntabs;i++) if (tables[i])
+   {
+    sfree(&memoryl, (void**)(&tables[i]));
+    tables[i]=NULL;
    }
- if (tables) 
-   { 
+ if (tables)
+   {
     tmp = (void*)tables;
-    sfree(&memoryl, &tmp); 
-    tables=NULL; 
+    sfree(&memoryl, &tmp);
+    tables=NULL;
    }
  shred_special_memlist(&memoryl);
 #endif
